@@ -116,13 +116,13 @@ if __name__ == '__main__':
     # ----------------------------------------------------------------------------------------------------------------
     # end...
 
-    except KeyError as ex:
-        print("csv_collator: KeyError: %s" % ex, file=sys.stderr)
-        exit(1)
-
     except KeyboardInterrupt:
         print(file=sys.stderr)
 
+    except KeyError as ex:
+        print("csv_collator: %s" % repr(ex), file=sys.stderr)
+        exit(1)
+
     finally:
         if collator is not None:
             collator.close()
