@@ -130,13 +130,13 @@ if __name__ == '__main__':
     # ----------------------------------------------------------------------------------------------------------------
     # end...
 
-    except KeyError as ex:
-        print("csv_segmentor: KeyError: %s" % ex, file=sys.stderr)
-        exit(1)
-
     except KeyboardInterrupt:
         print(file=sys.stderr)
 
+    except KeyError as ex:
+        print("csv_segmentor: %s" % repr(ex), file=sys.stderr)
+        exit(1)
+
     finally:
         if segmentor is not None:
             segmentor.close()
