@@ -30,6 +30,7 @@ SEE ALSO
 scs_analysis/cognito_credentials
 """
 
+import logging
 import requests
 import sys
 
@@ -37,7 +38,7 @@ from scs_analysis.cmd.cmd_organisation_devices import CmdOrganisationDevices
 
 from scs_core.aws.config.project import Project
 
-from scs_core.aws.security.cognito_login_manager import CognitoUserLoginManager
+from scs_core.aws.security.cognito_login_manager import CognitoLoginManager
 from scs_core.aws.security.cognito_user import CognitoUserCredentials
 
 from scs_core.aws.security.organisation import Organisation, OrganisationPathRoot, OrganisationDevice
@@ -53,7 +54,6 @@ from scs_core.sys.logging import Logging
 from scs_host.sys.host import Host
 
 
-# TODO: organisation_devices: {'message': 'Missing Authentication Token'}
 # --------------------------------------------------------------------------------------------------------------------
 
 if __name__ == '__main__':
@@ -63,7 +63,7 @@ if __name__ == '__main__':
     auth = None
     cognito = None
     org = None
-    report = None
+    report = []
 
     try:
         # ------------------------------------------------------------------------------------------------------------
@@ -75,7 +75,7 @@ if __name__ == '__main__':
             cmd.print_help(sys.stderr)
             exit(2)
 
-        Logging.config('organisation_devices', verbose=cmd.verbose)
+        Logging.config('organisation_devices', level=logging.DEBUG)
         logger = Logging.getLogger()
 
         logger.info(cmd)
@@ -105,7 +105,7 @@ if __name__ == '__main__':
         # ------------------------------------------------------------------------------------------------------------
         # auth...
 
-        gatekeeper = CognitoUserLoginManager(requests)
+        gatekeeper = CognitoLoginManager(requests)
 
         # CognitoUserCredentials...
         if not CognitoUserCredentials.exists(Host, name=cmd.credentials_name):
@@ -119,11 +119,11 @@ if __name__ == '__main__':
             logger.error("incorrect password")
             exit(1)
 
-        try:
-            auth = gatekeeper.login(credentials)
 
-        except HTTPException as ex:
-            logger.error(ex.data)
+        auth = gatekeeper.user_login(credentials)
+
+        if not auth.is_ok():
+            logger.error("login: %s" % auth.authentication_status.description)
             exit(1)
 
 
@@ -165,27 +165,8 @@ if __name__ == '__main__':
 
             manager.assert_device(auth.id_token, report)
 
-        if cmd.expire:
-            project = Project.construct(cmd.project_organisation, cmd.project_group, cmd.project_location)
-            device_path = project.device_path + '/'
-            location_path = project.location_path + '/'
-
-            report = manager.get_device(auth.id_token, cmd.device_tag, org.org_id,
-                                        device_path, location_path)
-
-            if report is None:
-                logger.error("no device found.")
-                exit(1)
-
-            report.end_datetime = LocalizedDatetime.now()
-            manager.assert_device(auth.id_token, report)
-
         if cmd.delete:
-            project = Project.construct(cmd.project_organisation, cmd.project_group, cmd.project_location)
-            device_path = project.device_path + '/'
-            location_path = project.location_path + '/'
-
-            manager.delete_device(auth.id_token, cmd.device_tag, org.org_id, device_path, location_path)
+            manager.delete_device(auth.id_token, cmd.device_tag)
 
 
     # ----------------------------------------------------------------------------------------------------------------
@@ -194,6 +175,9 @@ if __name__ == '__main__':
         if report is not None:
             print(JSONify.dumps(report, indent=cmd.indent))
 
+        if cmd.find:
+            logger.info("found: %s" % len(report))
+
     except KeyboardInterrupt:
         print(file=sys.stderr)
 
