@@ -31,7 +31,7 @@ import sys
 
 from scs_analysis.cmd.cmd_organisation_path_roots import CmdOrganisationPathRoots
 
-from scs_core.aws.security.cognito_login_manager import CognitoUserLoginManager
+from scs_core.aws.security.cognito_login_manager import CognitoLoginManager
 from scs_core.aws.security.cognito_user import CognitoUserCredentials
 
 from scs_core.aws.security.organisation import Organisation, OrganisationPathRoot
@@ -82,7 +82,7 @@ if __name__ == '__main__':
         # ------------------------------------------------------------------------------------------------------------
         # auth...
 
-        gatekeeper = CognitoUserLoginManager(requests)
+        gatekeeper = CognitoLoginManager(requests)
 
         # CognitoUserCredentials...
         if not CognitoUserCredentials.exists(Host, name=cmd.credentials_name):
@@ -96,11 +96,10 @@ if __name__ == '__main__':
             logger.error("incorrect password")
             exit(1)
 
-        try:
-            auth = gatekeeper.login(credentials)
+        auth = gatekeeper.user_login(credentials)
 
-        except HTTPException as ex:
-            logger.error(ex.data)
+        if not auth.is_ok():
+            logger.error("login: %s" % auth.authentication_status.description)
             exit(1)
 
 
@@ -148,6 +147,9 @@ if __name__ == '__main__':
         if report is not None:
             print(JSONify.dumps(report, indent=cmd.indent))
 
+        if cmd.find:
+            logger.info("found: %s" % len(report))
+
     except KeyboardInterrupt:
         print(file=sys.stderr)
 
