@@ -32,7 +32,7 @@ import sys
 from scs_analysis.cmd.cmd_organisation_user_paths import CmdOrganisationUserPaths
 
 from scs_core.aws.security.cognito_user_finder import CognitoUserFinder
-from scs_core.aws.security.cognito_login_manager import CognitoUserLoginManager
+from scs_core.aws.security.cognito_login_manager import CognitoLoginManager
 from scs_core.aws.security.cognito_user import CognitoUserCredentials
 
 from scs_core.aws.security.organisation import OrganisationPathRoot, OrganisationUserPath
@@ -56,7 +56,7 @@ if __name__ == '__main__':
     auth = None
     cognito = None
     org = None
-    report = None
+    report = []
 
     try:
         # ------------------------------------------------------------------------------------------------------------
@@ -89,7 +89,7 @@ if __name__ == '__main__':
         # ------------------------------------------------------------------------------------------------------------
         # auth...
 
-        gatekeeper = CognitoUserLoginManager(requests)
+        gatekeeper = CognitoLoginManager(requests)
 
         # CognitoUserCredentials...
         if not CognitoUserCredentials.exists(Host, name=cmd.credentials_name):
@@ -103,11 +103,10 @@ if __name__ == '__main__':
             logger.error("incorrect password")
             exit(1)
 
-        try:
-            auth = gatekeeper.login(credentials)
+        auth = gatekeeper.user_login(credentials)
 
-        except HTTPException as ex:
-            logger.error(ex.data)
+        if not auth.is_ok():
+            logger.error("login: %s" % auth.authentication_status.description)
             exit(1)
 
 
@@ -155,6 +154,9 @@ if __name__ == '__main__':
         if report is not None:
             print(JSONify.dumps(report, indent=cmd.indent))
 
+        if cmd.find:
+            logger.info("found: %s" % len(report))
+
     except KeyboardInterrupt:
         print(file=sys.stderr)
 
