@@ -34,7 +34,7 @@ import sys
 from scs_analysis.cmd.cmd_organisation_users import CmdOrganisationUsers
 
 from scs_core.aws.security.cognito_user_finder import CognitoUserFinder
-from scs_core.aws.security.cognito_login_manager import CognitoUserLoginManager
+from scs_core.aws.security.cognito_login_manager import CognitoLoginManager
 from scs_core.aws.security.cognito_user import CognitoUserCredentials
 
 from scs_core.aws.security.organisation import OrganisationUser
@@ -58,7 +58,7 @@ if __name__ == '__main__':
     auth = None
     cognito = None
     org = None
-    report = None
+    report = []
 
     try:
         # ------------------------------------------------------------------------------------------------------------
@@ -83,7 +83,7 @@ if __name__ == '__main__':
         # ------------------------------------------------------------------------------------------------------------
         # auth...
 
-        gatekeeper = CognitoUserLoginManager(requests)
+        gatekeeper = CognitoLoginManager(requests)
 
         # CognitoUserCredentials...
         if not CognitoUserCredentials.exists(Host, name=cmd.credentials_name):
@@ -97,11 +97,10 @@ if __name__ == '__main__':
             logger.error("incorrect password")
             exit(1)
 
-        try:
-            auth = gatekeeper.login(credentials)
+        auth = gatekeeper.user_login(credentials)
 
-        except HTTPException as ex:
-            logger.error(ex.data)
+        if not auth.is_ok():
+            logger.error("login: %s" % auth.authentication_status.description)
             exit(1)
 
 
@@ -135,9 +134,13 @@ if __name__ == '__main__':
         if cmd.find:
             if cmd.email:
                 report = manager.find_users_by_username(auth.id_token, cognito.username)
-            else:
+
+            elif cmd.org_label:
                 report = manager.find_users_by_organisation(auth.id_token, org.org_id)
 
+            else:
+                report = manager.find_users(auth.id_token)
+
         if cmd.retrieve:
             report = manager.get_user(auth.id_token, cognito.username, org.org_id)
 
@@ -173,6 +176,9 @@ if __name__ == '__main__':
         if report is not None:
             print(JSONify.dumps(report, indent=cmd.indent))
 
+        if cmd.find:
+            logger.info("found: %s" % len(report))
+
     except KeyboardInterrupt:
         print(file=sys.stderr)
 
