@@ -30,7 +30,7 @@ import sys
 
 from scs_analysis.cmd.cmd_organisations import CmdOrganisations
 
-from scs_core.aws.security.cognito_login_manager import CognitoUserLoginManager
+from scs_core.aws.security.cognito_login_manager import CognitoLoginManager
 from scs_core.aws.security.cognito_user import CognitoUserCredentials
 
 from scs_core.aws.security.organisation import Organisation
@@ -64,7 +64,7 @@ if __name__ == '__main__':
             cmd.print_help(sys.stderr)
             exit(2)
 
-        Logging.config('organisations', verbose=cmd.verbose)
+        Logging.config('organisations', verbose=cmd.verbose)       # level=logging.DEBUG
         logger = Logging.getLogger()
 
         logger.info(cmd)
@@ -89,25 +89,24 @@ if __name__ == '__main__':
         # ------------------------------------------------------------------------------------------------------------
         # auth...
 
-        gatekeeper = CognitoUserLoginManager(requests)
+        gatekeeper = CognitoLoginManager(requests)
 
         # CognitoUserCredentials...
-        if not CognitoUserCredentials.exists(Host):
+        if not CognitoUserCredentials.exists(Host, name=cmd.credentials_name):
             logger.error("Cognito credentials not available.")
             exit(1)
 
         try:
             password = CognitoUserCredentials.password_from_user()
-            credentials = CognitoUserCredentials.load(Host, encryption_key=password)
+            credentials = CognitoUserCredentials.load(Host, name=cmd.credentials_name, encryption_key=password)
         except (KeyError, ValueError):
             logger.error("incorrect password")
             exit(1)
 
-        try:
-            auth = gatekeeper.login(credentials)
+        auth = gatekeeper.user_login(credentials)
 
-        except HTTPException as ex:
-            logger.error(ex.data)
+        if not auth.is_ok():
+            logger.error("login: %s" % auth.authentication_status.description)
             exit(1)
 
 
@@ -121,7 +120,7 @@ if __name__ == '__main__':
         # run...
 
         if cmd.find:
-            report = manager.find_organisations(auth.id_token)
+            report = sorted(manager.find_organisations(auth.id_token))
 
         if cmd.create:
             org = Organisation(0, cmd.label, cmd.long_name, cmd.url, cmd.owner)
@@ -153,12 +152,12 @@ if __name__ == '__main__':
                 exit(1)
 
             # check...
-            response = StdIO.prompt('Are you sure (Y/n)?')
+            response = StdIO.prompt('Are you sure? (Y/n)')
             if response != 'Y':
                 exit(0)
 
             # delete...
-            manager.delete_organisation(auth.id_token, cmd.delete)
+            manager.delete_organisation(auth.id_token, org.org_id)
 
 
     # ----------------------------------------------------------------------------------------------------------------
@@ -167,6 +166,9 @@ if __name__ == '__main__':
         if report is not None:
             print(JSONify.dumps(report, indent=cmd.indent))
 
+        if cmd.find:
+            logger.info("found: %s" % len(report))
+
     except KeyboardInterrupt:
         print(file=sys.stderr)
 
