@@ -102,13 +102,13 @@ if __name__ == '__main__':
     # ----------------------------------------------------------------------------------------------------------------
     # end...
 
-    except KeyError as ex:
-        print("sample_min: KeyError: %s" % ex, file=sys.stderr)
-        exit(1)
-
     except KeyboardInterrupt:
         print(file=sys.stderr)
 
+    except KeyError as ex:
+        print("sample_min: %s" % repr(ex), file=sys.stderr)
+        exit(1)
+
     finally:
         if cmd.verbose:
             print("sample_min: documents: %d processed: %d" % (document_count, processed_count), file=sys.stderr)
