@@ -183,12 +183,12 @@ if __name__ == '__main__':
     # ----------------------------------------------------------------------------------------------------------------
     # end...
 
-    except KeyError as ex:
-        logger.error("KeyError: %s" % ex)
-        exit(1)
-
     except KeyboardInterrupt:
         print(file=sys.stderr)
 
+    except KeyError as ex:
+        logger.error(repr(ex))
+        exit(1)
+
     finally:
         logger.info("documents: %d processed: %d output: %d" % (document_count, processed_count, output_count))
